@@ -667,7 +667,7 @@ SASIndexNodePutValIndexed (SASIndexNode_t header, short pos, void *val)
 
 // we must return
 // a combined "found" and "position" result. If "found"
-// result is >=0 and == "postion". Otherwise result < 0 and
+// result is >=0 and == "position". Otherwise result < 0 and
 // "position == result + 256;
 short
 SASIndexNodeSearchNode (SASIndexNode_t header, SASIndexKey_t * target)
@@ -1352,7 +1352,7 @@ SASIndexNodeSplit (SASIndexNode_t node_t,
       median = (short) (min + 1);
     }
 #ifdef __SASDebugPrint__
-  sas_printf ("Split@%p x=%p k=%hd median=%hd lock_on=%d\n", node, xref->key, k, median, lock_on);
+  sas_printf ("Split@%p x=%p k=%hd median=%ld lock_on=%d\n", node, xref->key, k, median, lock_on);
 #endif
 
   if (lock_on == LOCK_ON)
@@ -1624,7 +1624,7 @@ SASIndexNodeRemove (SASIndexNode_t node_t, short pos,
 #endif
 
   if (q != NULL)
-    {				// dispose of q, since it is no longer accessable 
+    {				// dispose of q, since it is no longer accessible 
 #ifdef __SASDebugPrint__
       sas_printf ("Remove: delete branch for pos=%hd @%p\n", pos, q);
 #endif
@@ -1968,7 +1968,7 @@ SASIndexNodeRecDelete (SASIndexNode_t header, SASIndexKey_t * target,
 	    {
 	      found = SASIndexNodeRecDelete (q, node->keys[k], lock_on);
 #if __SASDebugPrint__ > 1
-	      sas_printf ("RecDelete after Sucessor found=%d\n", found);
+	      sas_printf ("RecDelete after Successor found=%d\n", found);
 	      sas_printf ("RecDelete: subtree=");
 	      SASIndexNodePrint (header);
 	      sas_printf ("\n");
