@@ -32,6 +32,12 @@
 #include "sphthread.h"
 #include "sphtimer.h"
 
+#ifdef LONGCHECK
+# define ITERATIONS 100000000
+#else
+# define ITERATIONS 10000000
+#endif
+
 static int N_PROC_CONF = 1;
 static int num_threads = 1;
 static long thread_iterations;
@@ -54,8 +60,10 @@ fill_test_parallel_thread (void *arg)
 	SPHLFLogger_t logger;
     long result = 0;
     int tn = (int) (long int) arg;
+#ifdef DEBUG_PRINT
     pid_t tid = sphFastGetTID();
     char number[128];
+#endif
 
     logger = log_lst[tn];
 
@@ -81,8 +89,10 @@ fill_test_thread (void *arg)
 {
     int tn = (int) (long int) arg;
     long result = 0;
+#ifdef DEBUG_PRINT
     pid_t tid = sphFastGetTID();
     char number[128];
+#endif
 
     SASThreadSetUp ();
 #ifdef DEBUG_PRINT
@@ -107,13 +117,16 @@ launch_test_threads (int t_cnt, test_ptr_t test_f,
 {
   long int n;
   pthread_t th[max_threads];
-  int tid;
-  int pid;
   long thread_result;
   int result = 0;
+#ifdef DEBUG_PRINT
+  int tid;
+  int pid;
 
   pid = getpid();
   tid = sphdeGetTID();
+#endif
+
   thread_iterations = iterations / t_cnt;
 #ifdef DEBUG_PRINT
   printf("creating thread from pid/tid = %d/%d\n", 
@@ -430,7 +443,7 @@ test_thread_log_verify(SPHLFLogger_t logger)
 	SPHLFLoggerHandle_t *handlex, handle5;
 	sphpid16_t entry_pid, entry_tid;
 	SPHLFLogIterator_t *iter, iter0;
-	sphtimer_t entry_timestamp, prev_timestamp;
+	sphtimer_t entry_timestamp;
 	int rtn = 0;	
 	long i;
 
@@ -460,7 +473,6 @@ test_thread_log_verify(SPHLFLogger_t logger)
 		return (rtn + 10);
 	}
 
-	prev_timestamp = 0LL;
 	do
 	{
 		handlex = SPHLFLoggerIteratorNext (iter, &handle5);
@@ -502,7 +514,6 @@ test_thread_log_verify(SPHLFLogger_t logger)
 						   temp0_i, temp1_i, temp2_i);
 				rtn++;
 			}
-			prev_timestamp = entry_timestamp;
 		}
 	} while (handlex);
 	
@@ -634,7 +645,7 @@ test_thread_wraplog_verify(SPHLFLogger_t logger)
 	sphpid16_t entry_pid, entry_tid;
 	SPHLFLogIterator_t *iter, iter0;
 	int	*tarray;
-	sphtimer_t entry_timestamp, prev_timestamp;
+	sphtimer_t entry_timestamp;
 	int rtn = 0;	
 	long i;
 
@@ -663,8 +674,7 @@ test_thread_wraplog_verify(SPHLFLogger_t logger)
 				logger, &iter0, iter);
 		return (rtn + 10);
 	}
-	
-	prev_timestamp = 0LL;
+
 	do
 	{
 		handlex = SPHLFLoggerIteratorNext (iter, &handle5);
@@ -707,7 +717,6 @@ test_thread_wraplog_verify(SPHLFLogger_t logger)
 						temp0_i, temp1_i, temp2_i);
 				rtn++;
 			}
-			prev_timestamp = entry_timestamp;
 		}
 	} while (handlex);
 	
@@ -864,7 +873,7 @@ int
 test_thread_wraplog_parallel_verify(void)
 {
 
-	int rc, rtn = 0;
+	int rtn = 0;
 	int i;
 
 	for (i = 0; i < num_threads; i++)
@@ -1066,7 +1075,7 @@ int main ()
 		rc2 = test_wraplog_init(SegmentSize);
 		if (rc2 == 0)
 		{
-			p10 = 100000000;
+			p10 = ITERATIONS;
 			test_func = test_thread_wraplog_fill;
 			printf("start test_thread_wraplog_fill (%p,%zu)\n",
 				logger, units);
@@ -1096,7 +1105,7 @@ int main ()
 			rc3 = test_wraplog_reset();
 			if (rc3 == 0)
 			{
-				p10 = 100000000;
+				p10 = ITERATIONS;
 				test_func = test_thread_wraplog_fill_strong;
 				printf("start test_thread_wraplog_fill_strong (%p,%zu)\n",
 					logger, units);
@@ -1127,7 +1136,7 @@ int main ()
 			rc3 = test_wraplog_reset();
 			if (rc3 == 0)
 			{
-				p10 = 100000000;
+				p10 = ITERATIONS;
 				test_func = test_thread_wraplog_fill_weak;
 				printf("start test_thread_wraplog_fill_weak (%p,%zu)\n",
 					logger, units);
@@ -1160,7 +1169,7 @@ int main ()
 			rc2 = test_wraplog_parallel_init(SegmentSize);
 			if (rc2 == 0)
 			{
-				p10 = 100000000;
+				p10 = ITERATIONS;
 				test_func = test_thread_wraplog_fill;
 				printf("start test_thread_wraplog_parallel_fill (%p,%zu)\n",
 					logger, units);
@@ -1190,7 +1199,7 @@ int main ()
 				rc3 = test_wraplog_parallel_reset();
 				if (rc3 == 0)
 				{
-					p10 = 100000000;
+					p10 = ITERATIONS;
 					test_func = test_thread_wraplog_fill_strong;
 					printf("start test_thread_wraplog_fill_parallel_strong (%p,%zu)\n",
 						logger, units);
@@ -1221,7 +1230,7 @@ int main ()
 				rc3 = test_wraplog_parallel_reset();
 				if (rc3 == 0)
 				{
-					p10 = 100000000;
+					p10 = ITERATIONS;
 					test_func = test_thread_wraplog_fill_nolock;
 					printf("start test_thread_wraplog_fill_parallel_nolock (%p,%zu)\n",
 						logger, units);
